@@ -13,6 +13,9 @@
 /* The length of the tag */
 #define GIITAGLEN	FIXME_DEFINE_THIS!
 
+/* Define if your system has dlopen */
+#undef HAVE_DLOPEN
+
 /* Define if ggUSleep is a #define in ggi/system.h */
 #undef GG_USLEEP_DEFINED
 
@@ -22,9 +25,6 @@
 /* Define if sys/ioctl.h defines TIOCMSET */
 #undef HAVE_TIOCMSET
 
-/* Undefine to disable run-time debugging */
-#define DEBUG
-
 /* Define if your libc has a __malloc_hook */
 #undef HAVE_MALLOC_HOOK
 
@@ -33,3 +33,12 @@
 
 /*  Define if you have the sched_yield function.  */
 #undef HAVE_SCHED_YIELD
+
+/*  Defines for optional host-dependent ifdefs */
+#undef COMPILING_FOR_X86
+#undef COMPILING_FOR_SPARC64
+#undef COMPILING_FOR_ALPHA
+
+/*  Defines if CC can compile various asm opcodes  */
+#undef CC_CAN_CPUID
+#undef CC_CAN_AMASK
