@@ -1,5 +1,5 @@
 /*
- * demo.c - (c) 1998 Andreas Beck   becka@ggi-project.org
+ * demo.c - Author 1998 Andreas Beck   becka@ggi-project.org
  *
  * This is a demonstration of LibGII's functions and can be used as a 
  * reference programming example.
@@ -24,7 +24,7 @@
 
 void test_showevent(gii_event *ev)
 {
-	int y;
+	unsigned int y;
 	
 	printf("o:%8x ",ev->any.origin);
 	switch(ev->any.type)
@@ -105,7 +105,7 @@ int main(int argc, char **argv)
 	 * main() function. Most of them are pretty meaningless loop-counters
 	 * and helper-variables.
 	 */
-	int x;
+	int x, res;
 	struct timeval tval;
 
  	gii_input_t inp,inp2;
@@ -134,6 +134,7 @@ int main(int argc, char **argv)
 	{
 		event.any.type=evKeyPress;
 		event.any.size=sizeof(gii_key_event);
+		event.any.target=GII_EV_TARGET_QUEUE;
 		event.key.label=x;
 		event.key.button=x;
 		event.key.sym=x;
@@ -142,11 +143,10 @@ int main(int argc, char **argv)
 		tval.tv_usec = 100000*x;
 		test_gii_poll(inp,&tval);
 	}
-	giiClose(inp);
 
 	/* Open some input.
 	 */
-	if ((inp=giiOpen("input-stdin",NULL)) == NULL) {
+	if ((inp2=giiOpen("input-stdin",NULL)) == NULL) {
 		fprintf(stderr,
 			"%s: unable to open stdin-source, exiting.\n",
 			argv[0]);
@@ -158,16 +158,7 @@ int main(int argc, char **argv)
 	{
 		tval.tv_sec = 0;
 		tval.tv_usec = 100000*x;
-		test_gii_poll(inp,&tval);
-	}
-	printf("Doing test of input-pcjoy.\n");
-	if ((inp2=giiOpen("input-pcjoy",NULL)) == NULL) {
-		fprintf(stderr,
-			"%s: unable to open pcjoy-source, exiting.\n",
-			argv[0]);
-		giiClose(inp);
-		giiExit();
-		exit(1);
+		test_gii_poll(inp2,&tval);
 	}
 	for(x=0;x<10;x++)
 	{
@@ -186,6 +177,75 @@ int main(int argc, char **argv)
 		test_gii_poll(inp,&tval);
 	}
 
+	printf("Splitting inputs.\n");
+	res = giiSplitInputs(inp, &inp2, GII_EV_ORIGIN_NONE, 0);
+	if (res == 1) {
+        	gii_input_t tmp;
+		tmp = inp2;
+		inp2 = inp;
+		inp = tmp;
+        } else if (res < 0) {
+		fprintf(stderr, "Failed to split inputs\n");
+		giiClose(inp);
+	}
+
+	printf("Doing test of each input from the split.\n");
+	for(x=0;x<3;x++)
+	{
+		event.any.type=evKeyPress;
+		event.any.size=sizeof(gii_key_event);
+		event.any.target=GII_EV_TARGET_QUEUE;
+		event.key.label=x;
+		event.key.button=x;
+		event.key.sym=x;
+		giiEventSend(inp,&event);
+		printf ("No event should be returned here:\n");
+		tval.tv_sec = 0;
+		tval.tv_usec = 100000*x;
+		test_gii_poll(inp2,&tval);
+	        printf ("It should be returned here:\n");
+		tval.tv_sec = 0;
+		tval.tv_usec = 100000*x;
+		test_gii_poll(inp,&tval);
+	}
+
+	for(x=0;x<3;x++)
+	{
+		event.any.type=evKeyPress;
+		event.any.size=sizeof(gii_key_event);
+		event.any.target=GII_EV_TARGET_QUEUE;
+		event.key.label=x;
+		event.key.button=x;
+		event.key.sym=x;
+		giiEventSend(inp2,&event);
+		printf ("No event should be returned here:\n");
+		tval.tv_sec = 0;
+		tval.tv_usec = 100000*x;
+		test_gii_poll(inp,&tval);
+		printf ("It should be returned here:\n");
+		tval.tv_sec = 0;
+		tval.tv_usec = 100000*x;
+		test_gii_poll(inp2,&tval);
+	}
+
+	printf("Joining inputs back together.\n");
+	inp=giiJoinInputs(inp,inp2);
+
+	printf("testing rejoined inputs\n");
+	for(x=0;x<5;x++)
+	{
+		event.any.type=evKeyPress;
+		event.any.size=sizeof(gii_key_event);
+		event.any.target=GII_EV_TARGET_QUEUE;
+		event.key.label=x;
+		event.key.button=x;
+		event.key.sym=x;
+		if ( x & 1 ) giiEventSend(inp2,&event);
+		tval.tv_sec = 0;
+		tval.tv_usec = 100000*x;
+		test_gii_poll(inp,&tval);
+	}
+
 	giiClose(inp);
 
 	/* Now close down LibGII. */
