@@ -1,9 +1,9 @@
-/* $Id: mhub.c,v 1.6 1999/05/10 20:30:25 marcus Exp $
+/* $Id: mhub.c,v 1.1.1.1.2.1 2003/04/12 16:15:44 cegger Exp $
 ******************************************************************************
 
    mhub - A LibGII -> mouse protocol converter
 
-   Copyright (C) 1998	Marcus Sundberg		[marcus@ggi-project.org]
+   Copyright (C) 1998-2000 Marcus Sundberg	[marcus@ggi-project.org]
 
    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the "Software"),
@@ -27,6 +27,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <unistd.h>
 
 #include "config.h" /* For autoconf defines */
@@ -56,7 +57,7 @@ typedef struct {
 } remap;
 
 static char *progname;
-static gii_input_t *inp;
+static gii_input_t inp;
 static int num_dataout = 0;
 static int num_butout = 0;
 static int data_fds[MAX_OUTPUTS];
@@ -69,7 +70,7 @@ static remap *remaps = NULL;
 
 static int debug = 0;
 static int exit_on_sigpipe = 0;
-static int min_extended_button = 4;
+static unsigned int min_extended_button = 4;
 static int wheel_up_button = 0;
 static int wheel_down_button = 0;
 
