@@ -1,4 +1,4 @@
-/* $Id: parse.c,v 1.10 1999/02/25 15:00:51 marcus Exp $
+/* $Id: parse.c,v 1.4 2002/10/15 21:56:19 skids Exp $
 ******************************************************************************
 
    LibGG - Parsing code
@@ -135,7 +135,7 @@ char *ggParseTarget(const char *str, char *target, int max)
 			if (bracket_count == 0) {
 				fprintf(stderr, "libgg: Bad target "
 					"descriptor : unexpected ')'\n");
-				*target = 0;
+				*target = '\0';
 				return NULL;
 			}
 
@@ -191,10 +191,61 @@ char *ggParseTarget(const char *str, char *target, int max)
                         |__str         |__result
  	
  		optlist[0].name: "parent"     (in)
- 		optlist11].name: "dither"     (in)
+ 		optlist[1].name: "dither"     (in)
  
  		optlist[0].result: "8"        (out)
- 		optlist11].result: "4"        (out)
+ 		optlist[1].result: "4"        (out)
+
+	Unnamed/ordered options support:
+
+	If in the optlist an option name is prefixed with a ":",
+	it is an eligible unnamed/ordered option.  The options
+	are first processed as described above, and if any of these
+	unnamed/ordered options are found in named (-optname=optvalue) 
+	form, the ":" is changed to a "-", and it is processed as a normal
+	named option.
+
+	After all named options have been processed, any leftover
+	fields are assigned to any unnamed/ordered options which
+	were not found in named form.  This is done in the order 
+	that these options appear in the optlist, and the prepended
+	':' is not changed in this case.  Options that were found in
+	named form are skipped.  Thus, it is possible to figure out 
+	if an option was found in named form, or was given a value 
+	from the fields left over after the named options, by checking 
+	if the first character of the option name has been changed 
+	to '-', or if it is still ':'.
+
+	For Example:
+
+		"terminfo:-physz==240,180:-path=/dev/ttyS0:vt100"
+			  ^					^
+			  |__str				|__result
+
+		... supposing that the option names are as follows:
+
+		optlist[0].name: ":path"
+		optlist[1].name: ":term"
+		optlist[2].name: "physz"
+
+		The option "physz" is a named option, and is 
+		found normally.  The option ":path" is an unnamed/ordered
+                option, but it is found in named form in the string 
+		"-path=/dev/ttyS0", and so the first unnamed/ordered
+		option belongs to the only remaining unnamed/ordered
+		option ":term".  The option names after ggParseOptions
+		returns are thus:
+
+		optlist[0].name: "-path"
+		optlist[1].name: ":term"
+		optlist[2].name: "physz"
+
+		...and the values that are retrieved for the options
+		are, respectively:
+ 
+		optlist[0].result: "/dev/ttyS0"
+		optlist[1].result: "vt100"
+		optlist[2].result: "=240,180"
 
 ******************************************************************************
 */
@@ -230,7 +281,7 @@ ggParseOptionValue(const char *str, char *buf)
 			str++;
 		}
 
-		if (len < MAX_OPTION_RESULT-1) {
+		if (len < GG_MAX_OPTION_RESULT-1) {
 			buf[len++] = *str;
 		}
 	}
@@ -241,11 +292,10 @@ ggParseOptionValue(const char *str, char *buf)
 
 char *ggParseOptions(const char *str, gg_option *optlist, int count)
 {
-	char name[MAX_OPTION_NAME]; int len;
+	char name[GG_MAX_OPTION_NAME]; int len;
 
 	gg_option *cur; int i;
 
-
 	for (;;) {
 
 		while (*str != '\0' && isspace((int)*str)) 
@@ -259,7 +309,7 @@ char *ggParseOptions(const char *str, gg_option *optlist, int count)
 		len = 0;
 
 		for (str++; ! TERMINATOR(*str) && (*str != '='); str++) {
-			if (len < MAX_OPTION_NAME-1) {
+			if (len < GG_MAX_OPTION_NAME-1) {
 				name[len++] = *str;
 			}
 		}
@@ -294,6 +344,12 @@ char *ggParseOptions(const char *str, gg_option *optlist, int count)
 				/* found it */
 				cur = optlist + i;
 			}
+			else if (*(optlist[i].name) == ':' &&
+				 strncmp(optlist[i].name + 1, name, len) == 0){
+				/* found it */
+				cur = optlist + i;
+				*(optlist[i].name) = '-';
+			}
 		}
 
 		if (cur == NULL) {
@@ -315,5 +371,16 @@ char *ggParseOptions(const char *str, gg_option *optlist, int count)
 			str++;
 	}
 
+	/* Now fill in any unfound eligible unnamed options from excess */
+	for (i=0; i < count; i++) {
+		if (*(optlist[i].name) == ':') {
+			cur = optlist + i;
+			str = ggParseOptionValue(str, cur->result);
+			if (*str == ':')
+				str++;
+		}
+	}
+
 	return (char *)str;
 }
+
