@@ -1,4 +1,4 @@
-/* $Id: gii.c,v 1.4 2001/06/30 09:56:14 soyt Exp $
+/* $Id: gii.c,v 1.11.2.4 2003/11/13 21:50:27 cegger Exp $
 ******************************************************************************
 
    Graphics library for GGI. General Input Interface.
@@ -29,15 +29,17 @@
 ******************************************************************************
 */
 
+#include "config.h"
+#include <ggi/internal/gii.h>
+#include <ggi/internal/gii_debug.h>
+#include <ggi/internal/gii-dl.h>
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <stdarg.h>
 #include <string.h>
 #include <ctype.h>
 
-#include <ggi/internal/gii.h>
-#include <ggi/internal/gii_debug.h>
-
 #ifdef HAVE_SIGNAL_H
 #include <signal.h>
 #endif
@@ -507,7 +509,11 @@ struct gii_input *_giiInputAlloc(void)
 	}
 
 	ret->version = GII_VERSIONCODE;
-	ret->mutex = NULL;
+	if (_gii_threadsafe) {
+		ret->mutex = ggLockCreate();
+	} else {
+		ret->mutex = NULL;
+	}
 	ret->next = ret->prev = ret;	/* Ring structure ... self<->self */
 	ret->dlhand = NULL;
 	ret->devinfo = NULL;
@@ -542,6 +548,14 @@ void _giiInputFree(struct gii_input *inp)
 			_giiCacheFree(inp->cache);
 		}
 	}
+
+	/* Free the associated device info structures */
+	while(inp->devinfo) {
+		_giiUnregisterDevice(inp,inp->devinfo->origin);
+	}
+	if (inp->mutex) 
+		ggLockDestroy(inp->mutex);
+
 	free(inp);
 }
 
@@ -576,6 +590,56 @@ _giiPollall(struct gii_input *inp, gii_event_mask mask, void *arg)
 	return retmask;
 }
 
+/* Add a new device to an input source and
+ * return its origin, or 0 on error.
+ */
+uint32 _giiRegisterDevice(gii_input *inp,
+			  gii_cmddata_getdevinfo  *dev,
+			  gii_cmddata_getvalinfo  *val) {
+	gii_deviceinfo * ret;
+	
+	ret = calloc(1, sizeof(*ret));
+	if (ret != NULL) {
+		ret->dev=dev;
+		ret->val=val;
+		/* The first dev always has the highest origin */
+		if(inp->devinfo==NULL)
+			ret->origin=inp->origin;
+		else
+			ret->origin=inp->devinfo->origin+1;
+		ret->next=inp->devinfo;
+		inp->devinfo=ret;
+		return ret->origin;
+	}
+	return 0;
+}
+
+/* Remove a device given by its origin.
+ */
+int _giiUnregisterDevice(gii_input *inp, uint32 origin) {
+
+	gii_deviceinfo *t, *curr;
+	
+	if(inp->devinfo==NULL) return -1;
+	
+	if(inp->devinfo->origin==origin) {
+		t=inp->devinfo;
+		inp->devinfo=inp->devinfo->next;
+		free(t);
+		return 0;
+	}
+	curr=inp->devinfo;
+	while(curr->next) {
+		if(curr->next->origin==origin) {
+			t=curr->next;
+			curr->next=curr->next->next;
+			free(t);
+			return 0;
+		}
+		curr=curr->next;
+	}
+	return -1;
+}
 
 /*
  * ** Opening/Closing/Joining of sources **
@@ -787,20 +851,33 @@ int giiSplitInputs(struct gii_input *inp, struct gii_input **newhand,
 
 	if (inp == NULL) return GGI_EARGINVAL;
 
+	/* Request is bogus - just one input in there. Abort.
+	 */
+	if (inp->next == inp) return GGI_ENOTFOUND;
+
+	/* Make sure noone messes with the queue or the input while we
+	 * dissect it.
+	 */
 	if (_gii_threadsafe) {
 		ggLock(inp->mutex);
 		ggLock(inp->queue->mutex);
 	}
 
-	if (inp->next == inp) return GGI_ENOTFOUND;
-
 	idx = inp;
 	do {
+		/* walk the queue until the right origin is found. */
+
 		if ((origin == idx->origin) || 
 		    (origin == GII_EV_ORIGIN_NONE)) {
-			if (inp == idx) {
 
-				_giiEvQueueAllocate(inp);
+			if (inp == idx) {
+				/* Ooops - we try to split off the _first_ input. This is a special case.
+				 */
+
+				/* Make a new queue for me. Old is 
+				 * retained due to pointers in other inputs. 
+				 */
+				_giiEvQueueAllocate(inp); 
 				inp->safequeue = NULL;
 				if (inp->cache != NULL) {
 					inp->cache->count--;
@@ -810,8 +887,8 @@ int giiSplitInputs(struct gii_input *inp, struct gii_input **newhand,
 					inp->cache->count++;
 				}
 
+				/* lock adjacent inputs as they will be changed now (relink) */
 				if (_gii_threadsafe) {
-					ggUnlock(inp->next->queue->mutex);
 					ggLock(inp->next->mutex);
 					if (inp->next != inp->prev)
 						ggLock(inp->prev->mutex);
@@ -819,25 +896,35 @@ int giiSplitInputs(struct gii_input *inp, struct gii_input **newhand,
 				inp->next->prev = inp->prev;
 				inp->prev->next = inp->next;
 				*newhand = inp->next;
+				_giiUpdateCache(*newhand);
+				/* unlock adjacent inputs again. */
 				if (_gii_threadsafe) {
 					if (inp->next != inp->prev)
 						ggUnlock(inp->prev->mutex);
 					ggUnlock(inp->next->mutex);
+					/* Look closely:
+					 * inp->queue has been overwritten during 
+					 * _giiEvQueueAllocate(inp); However 
+					 * inp->queue->mutex ist still locked.
+					 * inp->next->queue has a copy of the old 
+					 * contents of inp->queue, so we use that.
+					 */
+					ggUnlock(inp->next->queue->mutex);
 				}
+				/* selflink myself. */
 				inp->next = inp;
 				inp->prev = inp;
-				if (_gii_threadsafe) ggUnlock(inp->mutex);
+				_giiUpdateCache(inp);
+				if (_gii_threadsafe) {
+					ggUnlock(inp->mutex);
+				}
 				/* newhand may still be a joined input,
 				 * so we inform the user of that. */
 				return 1;
 			}
+			/* inp!=idx */
 			if (_gii_threadsafe) {
-				ggLock(idx->mutex);
-				if (idx->next != inp)
-					ggLock(inp->next->mutex);
-				if (idx->prev != inp &&
-				    idx->next != idx->prev)
-					ggLock(inp->prev->mutex);
+				ggLock(idx->mutex); /* no check needed as idx!=inp by definition */
 			}
 			_giiEvQueueAllocate(idx);
 			inp->safequeue = NULL;
@@ -848,25 +935,38 @@ int giiSplitInputs(struct gii_input *inp, struct gii_input **newhand,
 				idx->cache = _giiCacheAlloc();
 				idx->cache->count++;
 			}
+			if (_gii_threadsafe) {
+				if (idx->next != inp)
+					ggLock(idx->next->mutex);
+				if (idx->prev != inp)
+					ggLock(idx->prev->mutex);
+				/* the case idx->prev==idx->next cannot happen, 
+				 * because that would have to be inp, then. 
+				 * Otherwise the circular list would be 
+				 * corrupted already anyway.
+				 */
+			}
 			idx->prev->next = idx->next;
 			idx->next->prev = idx->prev;
 			if (_gii_threadsafe) {
-				if (idx->prev != inp &&
-				    idx->next != idx->prev)
-					ggUnlock(inp->prev->mutex);
+				if (idx->prev != inp)
+					ggUnlock(idx->prev->mutex);
 				if (idx->next != inp)
-					ggUnlock(inp->next->mutex);
+					ggUnlock(idx->next->mutex);
 			}
-			*newhand = idx;
 			idx->next = idx;
 			idx->prev = idx;
+			*newhand = idx;
+			_giiUpdateCache(*newhand);
+			_giiUpdateCache(inp);
 			if (_gii_threadsafe) {
 				ggUnlock(idx->mutex);
 				ggUnlock(inp->queue->mutex);
 				ggUnlock(inp->mutex);
 			}
 			return GGI_OK;
-		}
+		} /* found origin to split off */
+
 		idx = idx->next;
 	} while (idx != inp);
 
