@@ -1,4 +1,4 @@
-/* $Id: events.h,v 1.1.1.1 2001/05/12 23:00:13 cegger Exp $
+/* $Id: events.h,v 1.1.1.1.2.1 2003/04/14 20:54:23 cegger Exp $
 ******************************************************************************
 
    LibGII event definitions
@@ -127,11 +127,11 @@ typedef struct {
 ******************************************************************************
 */
 
-#define GII_CMDFLAG_NODATA	(1<<31)	/* Event has no data */
-#define GII_CMDFLAG_PRIVATE	(1<<30) /* The code is specific to a certain
-					   inputlib */
-#define GII_CMDFLAG_EXTERNAL	(1<<29)	/* Event is sent to/from an external
-					   system (like LibGGI) */
+#define GII_CMDFLAG_NODATA	((uint32)(1<<31))	/* Event has no data */
+#define GII_CMDFLAG_PRIVATE	((uint32)(1<<30))	 /* The code is specific to a certain
+							   inputlib */
+#define GII_CMDFLAG_EXTERNAL	((uint32)(1<<29))	/* Event is sent to/from an external
+							   system (like LibGGI) */
 
 
 /*	These are used internally or to/from the application.
@@ -162,15 +162,15 @@ typedef struct {
 
 /* This one is posted, if at least one event has been lost due to queue 
    overflow: */
-#define GII_CMDCODE_EVENTLOST		(0x01 | GII_CMDFLAG_NODATA)
+#define GII_CMDCODE_EVENTLOST		((uint32)0x01 | GII_CMDFLAG_NODATA)
 
 /* This event tell inputlibs that the application prefer absolute pointer
    events. */
-#define GII_CMDCODE_PREFER_ABSPTR	(0x02 | GII_CMDFLAG_NODATA)
+#define GII_CMDCODE_PREFER_ABSPTR	((uint32)0x02 | GII_CMDFLAG_NODATA)
 
 /* This event tell inputlibs that the application prefer relative pointer
    events. */
-#define GII_CMDCODE_PREFER_RELPTR	(0x03 | GII_CMDFLAG_NODATA)
+#define GII_CMDCODE_PREFER_RELPTR	((uint32)0x03 | GII_CMDFLAG_NODATA)
 
 /* This event is sent/received to require/get the capabilities of a device
  * as specified in target/origin.
@@ -178,7 +178,7 @@ typedef struct {
  * unplugged, whatever. Devices automatically report (detectable) state
  * changes via devinfo. But you need to re-query the valinfo records.
  */
-#define GII_CMDCODE_GETDEVINFO	(0x01)
+#define GII_CMDCODE_GETDEVINFO	((uint32)0x01)
 typedef struct {
 	
 	char		longname[75];
@@ -231,7 +231,7 @@ typedef enum {
 /* This event is sent/received to require/get detailed data about valuator
  * axis.
  */
-#define GII_CMDCODE_GETVALINFO	(0x02)
+#define GII_CMDCODE_GETVALINFO	((uint32)0x02)
 typedef struct {
 	
 	uint32		number;		/* Number of the valuator */
