@@ -1,9 +1,10 @@
-/* $Id: gii-dl.h,v 1.3 1999/02/21 21:31:27 marcus Exp $
+/* $Id: gii-dl.h,v 1.1.1.1 2001/05/12 23:00:14 cegger Exp $
 ******************************************************************************
 
    LibGII semi-internals. Are exported, but for source-use only.
  
    Copyright (C) 1998 Andreas Beck	[becka@ggi-project.org]
+   Copyright (C) 1999 Marcus Sundberg	[marcus@ggi-project.org]
 
    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the "Software"),
@@ -32,8 +33,11 @@
 
 /* Internal API calls
  */
+__BEGIN_DECLS
 
 int			_giiEvQueueAdd(gii_input *inp, gii_event *ev);
 struct gii_input	*_giiInputAlloc(void);
 
+__END_DECLS
+
 #endif /* _GGI_INTERNAL_SOURCE_H */
