@@ -1,4 +1,4 @@
-/* $Id: gii.h,v 1.2 2001/06/17 08:34:30 cegger Exp $
+/* $Id: gii.h,v 1.4.2.1 2003/04/14 20:54:25 cegger Exp $
 ******************************************************************************
 
    LibGII internals
@@ -31,7 +31,6 @@
 
 #define _INTERNAL_LIBGII
 
-#include "config.h"
 #include <ggi/system.h>
 #include <ggi/events.h>
 
@@ -132,7 +131,7 @@ typedef struct gii_input {
 #define GII_FLAGS_HASPOLLED	0x00000001
 
 #define GII_QUEUE_SIZE      8192
-#define GII_Q_THRESHOLD     (GII_QUEUE_SIZE - sizeof(gii_event) - 1)
+#define GII_Q_THRESHOLD     (GII_QUEUE_SIZE - (int)sizeof(gii_event) - 1)
 
 /* The threshold the point where events wrap back to the start of the
  * buffer.  Events are stored in the buffer in whole; they do not get
@@ -184,6 +183,13 @@ int _giiSafeMove(struct gii_input *toinp, struct gii_input *frominp);
 
 void _giiAsyncNotify(gii_input *inp);
 
+uint32 _giiRegisterDevice(gii_input *inp,
+			  gii_cmddata_getdevinfo  *dev,
+			  gii_cmddata_getvalinfo  *val);
+
+int              _giiUnregisterDevice(gii_input *inp,
+				      uint32 origin);
+
 __END_DECLS
 
 #endif /* _GGI_INTERNAL_GII_H */
