@@ -1,9 +1,9 @@
-/* $Id: gii_debug.h,v 1.5 1999/02/20 19:30:19 marcus Exp $
+/* $Id: gii_debug.h,v 1.1.1.1 2001/05/12 23:00:14 cegger Exp $
 ******************************************************************************
 
    LibGII debugging macros
 
-   Copyright (C) 1998	Marcus Sundberg		[marcus@ggi-project.org]
+   Copyright (C) 1998-1999 Marcus Sundberg	[marcus@ggi-project.org]
   
    Permission is hereby granted, free of charge, to any person obtaining a
    copy of this software and associated documentation files (the "Software"),
@@ -33,8 +33,18 @@
 #include <ggi/system.h>
 #include <ggi/gg.h>
 
+__BEGIN_DECLS
+
+/* Exported variables */
+#ifdef BUILDING_LIBGII
 extern uint32 _giiDebugState;
-extern int _giiDebugSync;
+extern int    _giiDebugSync;
+#else
+IMPORTVAR uint32 _giiDebugState;
+IMPORTVAR int    _giiDebugSync;
+#endif
+
+__END_DECLS
 
 /* Debugging types
  * bit 0 is reserved! */
@@ -49,11 +59,11 @@ extern int _giiDebugSync;
 #ifdef __GNUC__
 
 #ifdef DEBUG
-#define GIIDPRINT(form,args...)	    if (_giiDebugState) { ggDPrintf(_giiDebugSync,"LibGII",form, ##args); }
-#define GIIDPRINT_CORE(form,args...)   if (_giiDebugState & GIIDEBUG_CORE) { ggDPrintf(_giiDebugSync,"LibGII",form, ##args); }
-#define GIIDPRINT_MISC(form,args...)   if (_giiDebugState & GIIDEBUG_MISC) { ggDPrintf(_giiDebugSync,"LibGII",form, ##args); }
-#define GIIDPRINT_LIBS(form,args...)   if (_giiDebugState & GIIDEBUG_LIBS) { ggDPrintf(_giiDebugSync,"LibGII",form, ##args); }
-#define GIIDPRINT_EVENTS(form,args...) if (_giiDebugState & GIIDEBUG_EVENTS) { ggDPrintf(_giiDebugSync,"LibGII",form, ##args); }
+#define GIIDPRINT(args...)        if (_giiDebugState) { ggDPrintf(_giiDebugSync,"LibGII",args); }
+#define GIIDPRINT_CORE(args...)   if (_giiDebugState & GIIDEBUG_CORE) { ggDPrintf(_giiDebugSync,"LibGII",args); }
+#define GIIDPRINT_MISC(args...)   if (_giiDebugState & GIIDEBUG_MISC) { ggDPrintf(_giiDebugSync,"LibGII",args); }
+#define GIIDPRINT_LIBS(args...)   if (_giiDebugState & GIIDEBUG_LIBS) { ggDPrintf(_giiDebugSync,"LibGII",args); }
+#define GIIDPRINT_EVENTS(args...) if (_giiDebugState & GIIDEBUG_EVENTS) { ggDPrintf(_giiDebugSync,"LibGII",args); }
 #else /* DEBUG */
 #define GIIDPRINT(form,args...)		do{}while(0)
 #define GIIDPRINT_CORE(form,args...)	do{}while(0)
@@ -64,6 +74,8 @@ extern int _giiDebugSync;
 
 #else /* __GNUC__ */
 
+__BEGIN_DECLS
+
 static inline void GIIDPRINT(const char *form,...)
 {
 #ifdef DEBUG
@@ -139,6 +151,8 @@ static inline void GIIDPRINT_EVENTS(const char *form,...)
 #endif
 }
 
+__END_DECLS
+
 #endif /* __GNUC__ */
 
 
@@ -158,4 +172,30 @@ static inline void GIIDPRINT_EVENTS(const char *form,...)
 #define LIBGII_APPASSERT(x,str)	do{}while(0)
 #endif /* DEBUG */
 
+#ifdef DEBUG
+# define GIID0(x)	x
+#else
+# define GIID0(x)	/* empty */
+#endif
+
+#ifdef GIIDLEV
+# if GIIDLEV == 1
+#  define GIID1(x)	x
+#  define GIID2(x)	/* empty */
+#  define GIID3(x)	/* empty */
+# elif GIIDLEV == 2
+#  define GIID1(x)	x
+#  define GIID2(x)	x
+#  define GIID3(x)	/* empty */
+# elif GIIDLEV > 2
+#  define GIID1(x)	x
+#  define GIID2(x)	x
+#  define GIID3(x)	x
+# endif
+#else
+# define GIID1(x)	/* empty */
+# define GIID2(x)	/* empty */
+# define GIID3(x)	/* empty */
+#endif
+
 #endif /* _GGI_INTERNAL_GII_DEBUG_H */
