@@ -1,4 +1,4 @@
-/* $Id: input.c,v 1.2 2001/06/17 08:34:30 cegger Exp $
+/* $Id: input.c,v 1.5.2.1 2003/02/01 14:33:30 cegger Exp $
 ******************************************************************************
 
    fdselect inputlib - send information when filedescriptors become
@@ -30,6 +30,7 @@
 #include <string.h>
 #include <ctype.h>
 
+#include "config.h"
 #include <ggi/internal/gii-dl.h>
 #include <ggi/internal/gii_debug.h>
 
@@ -74,7 +75,7 @@ static gii_event_mask GII_fd_poll(gii_input *inp, void *arg)
 	ev.any.type=evInformation;
 	ev.any.origin=inp->origin;
 	ev.cmd.code   = GII_CMDFLAG_PRIVATE;
-	// fixme - be more precise !
+	/* fixme - be more precise ! */
 	_giiEvQueueAdd(inp, &ev);
 
 	return evInformation;
@@ -102,14 +103,6 @@ static gii_cmddata_getdevinfo devinfo =
 	0				/* no valuators */
 };
 
-static gii_deviceinfo xdevinfo =
-{
-	NULL,
-	0,
-	&devinfo,
-	NULL
-};
-
 static void send_devinfo(gii_input *inp)
 {
 	gii_event ev;
@@ -123,7 +116,7 @@ static void send_devinfo(gii_input *inp)
 	ev.any.origin = inp->origin;
 	ev.cmd.code   = GII_CMDCODE_GETDEVINFO;
 
-	dinfo = (gii_cmddata_getdevinfo *) &ev.cmd.data;
+	dinfo = (gii_cmddata_getdevinfo *) ev.cmd.data;
 	*dinfo = devinfo;
 
 	_giiEvQueueAdd(inp, &ev);
@@ -196,6 +189,12 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 	if ((priv = malloc(sizeof(fd_priv))) == NULL) {
 		return GGI_ENOMEM;
 	}
+	
+	if(_giiRegisterDevice(inp,&devinfo,NULL)==0) {
+		free(priv);
+		return GGI_ENOMEM;
+	}
+
 	inp->priv = priv;
 	priv->maxread = priv->maxwrite = priv->maxexcept = priv->maxfd = 0;
         FD_ZERO(&priv->readfds);
@@ -233,8 +232,6 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 	inp->GIIsendevent = GII_fd_sendevent;
 	inp->GIIeventpoll = GII_fd_poll;
 	inp->GIIclose = GII_fd_close;
-	inp->devinfo    = &xdevinfo;
-	xdevinfo.origin = inp->origin;
 
 	send_devinfo(inp);
 
