@@ -1,4 +1,4 @@
-/* $Id: input.c,v 1.2 2001/06/17 08:34:30 cegger Exp $
+/* $Id: input.c,v 1.4.2.3 2003/11/13 21:55:36 cegger Exp $
 ******************************************************************************
 
    Input-file: Read events from a file saved by filter-save
@@ -25,14 +25,15 @@
 ******************************************************************************
 */
 
+#include "config.h"
+#include <ggi/internal/gii-dl.h>
+#include <ggi/internal/gii_debug.h>
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
 
-#include <ggi/internal/gii-dl.h>
-#include <ggi/internal/gii_debug.h>
-
 
 enum outtype { STDIN, FIL, PIPE };
 
@@ -149,14 +150,6 @@ static gii_cmddata_getdevinfo devinfo =
 	~0,				/* all valuators */
 };
 
-static gii_deviceinfo xdevinfo =
-{
-	NULL,
-	0,
-	&devinfo,
-	NULL
-};
-
 static void send_devinfo(gii_input *inp)
 {
 	gii_event ev;
@@ -212,6 +205,11 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 		return GGI_ENOMEM;
 	}
 
+	if(_giiRegisterDevice(inp,&devinfo,NULL)==0) {
+		free(priv);
+		return GGI_ENOMEM;
+	}
+
 	if (args == NULL || *args == '\0') {
 		priv->type = STDIN;
 		priv->fil = stdin;
@@ -228,6 +226,7 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 		}
 		if (priv->fil == NULL) {
 			free(priv);
+			
 			return GGI_ENODEVICE;
 		}
 	}
@@ -259,8 +258,6 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 	inp->GIIsendevent = GIIsendevent;
 	inp->GIIeventpoll = GII_file_poll;
 	inp->GIIclose     = GII_file_close;
-	inp->devinfo    = &xdevinfo;
-	xdevinfo.origin = inp->origin;
 
 	send_devinfo(inp);
 
