@@ -1,4 +1,4 @@
-/* $Id: input.c,v 1.20 1999/05/16 15:48:41 marcus Exp $
+/* $Id: input.c,v 1.6.2.2 2003/04/14 20:54:27 cegger Exp $
 ******************************************************************************
 
    Linux_joy: input
@@ -37,8 +37,9 @@
 #include <fcntl.h>
 
 #include <linux/joystick.h>
-
+#include "config.h"
 #include <ggi/internal/gii.h>
+#include <ggi/internal/gii_debug.h>
 
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
@@ -170,7 +171,7 @@ GII_joystick_handle_data(gii_input *inp)
 	gii_event ev;
 	gii_event_mask result=0;
 
-	int i;
+	unsigned int i;
 
 
 	/* read the joystick packet */
@@ -317,14 +318,6 @@ static gii_cmddata_getvalinfo linux_joy_valinfo[MAX_NR_JAXES] =
     },
 };
 
-static gii_deviceinfo xdevinfo =
-{
-	NULL,
-	0,
-	&linux_joy_devinfo,
-	linux_joy_valinfo
-};
-
 static int GII_linux_joy_senddevinfo(gii_input *inp)
 {
 	JoystickHook *priv = JOYSTICK_HOOK(inp);
@@ -343,7 +336,7 @@ static int GII_linux_joy_senddevinfo(gii_input *inp)
 	ev.any.origin = inp->origin;
 	ev.cmd.code   = GII_CMDCODE_GETDEVINFO;
 
-	DI = (gii_cmddata_getdevinfo *) &ev.cmd.data;
+	DI = (gii_cmddata_getdevinfo *) ev.cmd.data;
 
 	*DI = linux_joy_devinfo;
 	
@@ -374,7 +367,7 @@ static int GII_linux_joy_sendvalinfo(gii_input *inp, int val)
 	ev.cmd.code   = GII_CMDCODE_GETVALINFO;
 
 
-	VI = (gii_cmddata_getvalinfo *) &ev.cmd.data;
+	VI = (gii_cmddata_getvalinfo *) ev.cmd.data;
 
 	*VI = linux_joy_valinfo[(val < 2) ? val : 2];
 	
@@ -384,8 +377,13 @@ static int GII_linux_joy_sendvalinfo(gii_input *inp, int val)
 		sprintf(buf, "%d", val);
 
 		VI->number = val;
+#ifdef HAVE_STRNCAT
+		strncat(VI->longname,  buf, 75);
+		strncat(VI->shortname, buf, 5);
+#else
 		strcat(VI->longname,  buf);
 		strcat(VI->shortname, buf);
+#endif
 	}
 
 	return _giiEvQueueAdd(inp, &ev);
@@ -457,6 +455,10 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 		filename = (char *) args;
 	}
 
+	if(_giiRegisterDevice(inp,&linux_joy_devinfo,linux_joy_valinfo)==0) {
+		return GGI_ENOMEM;
+	}
+
 	if ((ret = GII_joystick_init(inp, filename)) < 0) {
 		return ret;
 	}
@@ -472,8 +474,11 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 
 	inp->targetcan = emKey | emValuator;
 	inp->GIIseteventmask(inp, emKey | emValuator);
-	inp->devinfo    = &xdevinfo;	/* FIXME ! Length ! */
-	xdevinfo.origin = inp->origin;
+
+	/*
+	  inp->devinfo    = &xdevinfo;	 FIXME ! Length ! 
+	  xdevinfo.origin = inp->origin;
+	*/
 
 	inp->maxfd = JOYSTICK_HOOK(inp)->fd + 1;
 	FD_SET(JOYSTICK_HOOK(inp)->fd, &inp->fdset);
