@@ -1,4 +1,4 @@
-/* $Id: input.c,v 1.1.1.1 2001/05/12 23:00:22 cegger Exp $
+/* $Id: input.c,v 1.3.2.3 2004/04/17 17:49:36 cegger Exp $
 ******************************************************************************
 
    Linux_kbd: input via linux MEDIUMRAW mode.
@@ -25,7 +25,7 @@
 
 ******************************************************************************
 */
-
+#include "config.h"
 #include <ggi/internal/gii.h>
 
 #include <stdio.h>
@@ -204,7 +204,7 @@ GII_keyboard_init(gii_input *inp, char *filename)
 	if (ioctl(fd, KDGKBDIACR, &priv->accent_table) != 0) {
 		priv->accent_table.kb_cnt = 0;
 	} else {
-		int i;
+		unsigned int i;
 		for (i = 0; i < priv->accent_table.kb_cnt; i++) {
 			switch (priv->accent_table.kbdiacr[i].diacr) {
 			case '"':
@@ -287,7 +287,7 @@ static inline void
 handle_accent(linkbd_priv *priv, int symval, gii_event *ev)
 {
 	unsigned char diacr = priv->accent;
-	int i;
+	unsigned int i;
 
 	for (i = 0; i < priv->accent_table.kb_cnt; i++) {
 		if (priv->accent_table.kbdiacr[i].diacr == diacr &&
@@ -385,6 +385,13 @@ GII_keyboard_handle_data(gii_input *inp, int code)
 		ev.key.sym   = priv->keydown_sym[code];
 		ev.key.label = priv->keydown_label[code];
 	} else {
+		/* Temporarily switch back to the old mode because unicodes arent't
+		   available through table lookup in MEDIUMRAW
+		*/
+		if (ioctl(priv->fd, KDSKBMODE, priv->old_mode) < 0) {
+			GIIDPRINT_MISC("Linux-kbd: ioctl(KDSKBMODE) failed.\n");
+			return 0;
+		}
 		/* Look up the keysym without modifiers, which will give us
 		 * the key label (more or less).
 		 */
@@ -395,6 +402,7 @@ GII_keyboard_handle_data(gii_input *inp, int code)
 			return 0;
 		}
 		labelval = entry.kb_value;
+		if (priv->old_mode == K_UNICODE) labelval &= 0x0fff;
 
 		/* Now look up the full keysym in the kernel's table */
 
@@ -413,6 +421,12 @@ GII_keyboard_handle_data(gii_input *inp, int code)
 			return 0;
 		}
 
+		/* Switch back to MEDIUMRAW */
+		if (ioctl(priv->fd, KDSKBMODE, K_MEDIUMRAW) < 0) {
+			GIIDPRINT_MISC("Linux-kbd: ioctl(KDSKBMODE) failed.\n");
+			return 0;
+		}
+
 		switch (entry.kb_value) {
 
 		case K_HOLE:
@@ -425,6 +439,7 @@ GII_keyboard_handle_data(gii_input *inp, int code)
 			break;
 		}
 		symval = entry.kb_value;
+		if (priv->old_mode == K_UNICODE) symval &= 0x0fff;
 
 		_gii_linkey_trans(code, labelval, symval, &ev.key);
 
@@ -583,14 +598,6 @@ static gii_cmddata_getdevinfo devinfo =
 	0				/* num_axes */
 };
 
-static gii_deviceinfo xdevinfo =
-{
-	NULL,
-	0,
-	&devinfo,
-	NULL
-};
-
 static void send_devinfo(gii_input *inp)
 {
 	gii_event ev;
@@ -604,7 +611,7 @@ static void send_devinfo(gii_input *inp)
 	ev.any.origin = inp->origin;
 	ev.cmd.code   = GII_CMDCODE_GETDEVINFO;
 
-	dinfo = (gii_cmddata_getdevinfo *) &ev.cmd.data;
+	dinfo = (gii_cmddata_getdevinfo *) ev.cmd.data;
 	*dinfo = devinfo;
 
 	_giiEvQueueAdd(inp, &ev);
@@ -685,6 +692,10 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 		filename = (char *) args;
 	}
 
+	if(_giiRegisterDevice(inp,&devinfo,NULL)==0) {
+		return GGI_ENOMEM;
+	}
+
 	if (GII_keyboard_init(inp, filename) < 0) {
 		return GGI_ENODEVICE;
 	}
@@ -698,8 +709,6 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 
 	inp->targetcan = emKey;
 	inp->GIIseteventmask(inp, inp->targetcan);
-	inp->devinfo    = &xdevinfo;
-	xdevinfo.origin = inp->origin;
 
 	inp->maxfd = LINKBD_PRIV(inp)->fd + 1;
 	FD_SET(LINKBD_PRIV(inp)->fd, &inp->fdset);
