@@ -1,4 +1,4 @@
-/* $Id: mouse.h,v 1.5 1999/05/13 16:18:41 marcus Exp $
+/* $Id: mouse.h,v 1.2 2001/06/17 08:34:30 cegger Exp $
 ******************************************************************************
 
    Mouse inputlib header
@@ -26,16 +26,24 @@
 */
 
 #include <ggi/internal/gii-dl.h>
+#include <ggi/internal/gii_debug.h>
 
 #define MAX_PACKET_BUF	128
 
-typedef struct {
+
+/* Mouse init types */
+#define GII_MIT_DONTCARE	0	/* Continue if init fails. */
+#define GII_MIT_MUST		1	/* Fail if init fails. */
+#define GII_MIT_FALLBACK	2	/* Fall back to fbparser. */
+
+typedef struct parser_type {
 	char *names[8];				  /* Case insensitive names */
 	int (*parser)(gii_input *, uint8 *, int); /* Parser function */
 	int	 min_packet_len;
 	uint8	*init_data;
 	int	 init_len;
-	int	 must_init;	/* Fail if init fails */
+	int	 init_type;	/* Kind of init (see GII_MIT_*) */
+	struct parser_type *fbparser; /* Fallback parser type */
 } parser_type;
 	
 typedef struct {
@@ -54,6 +62,6 @@ typedef struct {
 
 #define MOUSE_PRIV(inp)  ((mouse_priv *) inp->priv)
 
-extern parser_type _gii_mouse_parsers[];
+extern parser_type *_gii_mouse_parsers[];
 
 extern giifunc_eventpoll	GII_mouse_poll;
