@@ -1,4 +1,4 @@
-/* $Id: packetparse.c,v 1.1.1.1 2001/05/12 23:00:27 cegger Exp $
+/* $Id: packetparse.c,v 1.2.2.1 2003/04/14 20:54:28 cegger Exp $
 ******************************************************************************
 
    Mouse packet parsing
@@ -25,7 +25,7 @@
 
 ******************************************************************************
 */
-
+#include "config.h"
 #include "mouse.h"
 #include <string.h>
 #include <unistd.h>
@@ -116,7 +116,8 @@ static int parse_null(gii_input *inp, uint8 *buf, int len)
 
 static int parse_ms(gii_input *inp, uint8 *buf, int len)
 {
-	int dx, dy, buttons;
+	int dx, dy;
+	unsigned int buttons;
 	mouse_priv *mpriv = MOUSE_PRIV(inp);
 
 	/* check header */
@@ -167,7 +168,8 @@ static int parse_ms(gii_input *inp, uint8 *buf, int len)
 
 static int parse_ms3(gii_input *inp, uint8 *buf, int len)
 {
-	int buttons, wheel;
+	int wheel;
+	unsigned int buttons;
 	mouse_priv *mpriv = MOUSE_PRIV(inp);
 
 	if (mpriv->parse_state == 0) {
@@ -231,7 +233,8 @@ static int parse_ms3(gii_input *inp, uint8 *buf, int len)
 
 static int parse_msc(gii_input *inp, uint8 *buf, int len)
 {
-	int dx, dy, buttons;
+	int dx, dy;
+	unsigned int buttons;
 	mouse_priv *mpriv = MOUSE_PRIV(inp);
 	static uint32 B_mousesys[] = {
 		0x0, 0x2, 0x4, 0x6, 0x1, 0x3, 0x5, 0x7
@@ -268,7 +271,8 @@ static int parse_msc(gii_input *inp, uint8 *buf, int len)
 
 static int parse_logi(gii_input *inp, uint8 *buf, int len)
 {
-	int dx, dy, buttons;
+	int dx, dy;
+	unsigned int buttons;
 	mouse_priv *mpriv = MOUSE_PRIV(inp);
 	static uint32 B_logitech[] = {
 		0x0, 0x2, 0x4, 0x6, 0x1, 0x3, 0x5, 0x7
@@ -305,7 +309,8 @@ static int parse_logi(gii_input *inp, uint8 *buf, int len)
 
 static int parse_sun(gii_input *inp, uint8 *buf, int len)
 {
-	int dx, dy, buttons;
+	int dx, dy;
+	unsigned int buttons;
 	mouse_priv *mpriv = MOUSE_PRIV(inp);
 	static uint32 B_sun[] = {
 		0x0, 0x2, 0x4, 0x6, 0x1, 0x3, 0x5, 0x7
@@ -359,7 +364,8 @@ static int parse_sun(gii_input *inp, uint8 *buf, int len)
 
 static int parse_mman(gii_input *inp, uint8 *buf, int len)
 {
-	int dx, dy, buttons;
+	int dx, dy;
+	unsigned int buttons;
 	mouse_priv *mpriv = MOUSE_PRIV(inp);
 	static uint32 B_mouseman[] = {
 		0x0, 0x2, 0x1, 0x3, 0x4, 0x6, 0x5, 0x7
@@ -423,7 +429,8 @@ static int parse_mman(gii_input *inp, uint8 *buf, int len)
 
 static int parse_ps2(gii_input *inp, uint8 *buf, int len)
 {
-	int dx, dy, buttons;
+	int dx, dy;
+	unsigned int buttons;
 	mouse_priv *mpriv = MOUSE_PRIV(inp);
 
 	/* Check header byte. */
@@ -457,7 +464,8 @@ static int parse_ps2(gii_input *inp, uint8 *buf, int len)
 
 static int parse_mmanps2(gii_input *inp, uint8 *buf, int len)
 {
-	int dx = 0, dy = 0, wheel = 0, buttons;
+	int dx = 0, dy = 0, wheel = 0;
+	unsigned int buttons;
 	mouse_priv *mpriv = MOUSE_PRIV(inp);
 
 	/* Check header byte. */
@@ -498,7 +506,8 @@ static int parse_mmanps2(gii_input *inp, uint8 *buf, int len)
 
 static int parse_imps2(gii_input *inp, uint8 *buf, int len)
 {
-	int dx, dy, wheel, buttons;
+	int dx, dy, wheel;
+	unsigned int buttons;
 	mouse_priv *mpriv = MOUSE_PRIV(inp);
 
 	if ((buf[0] & 0xc0) != 0) {
