@@ -1,4 +1,4 @@
-/* $Id: input.c,v 1.19 1999/03/20 15:28:23 becka Exp $
+/* $Id: input.c,v 1.4.2.3 2003/11/13 22:01:58 cegger Exp $
 ******************************************************************************
 
    SpaceOrb: input
@@ -33,6 +33,10 @@
 ******************************************************************************
 */
 
+#include "config.h"
+#include <ggi/internal/gii.h>
+#include <ggi/internal/gii_debug.h>
+
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
@@ -45,8 +49,6 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
-#include <ggi/internal/gii.h>
-
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -336,9 +338,7 @@ static int do_spaceorb_open(gii_input *inp, char *filename,
 			    int dtr, int rts, int baud)
 {
 	SpaceOrbHook *orb = SPACEORB_HOOK(inp);
-
-	struct termios new;
-
+	struct termios tio;
 
 	orb->fd = open(filename, O_RDWR | O_NOCTTY);
 
@@ -357,29 +357,28 @@ static int do_spaceorb_open(gii_input *inp, char *filename,
 /*		return GGI_ENODEVICE;		*/
 	}
 
-	new = orb->old_termios;
+	tio = orb->old_termios;
 
 	if (baud < 0) {
 		baud = B9600;
 	}
 	
-	new.c_cflag = CREAD | CLOCAL | HUPCL | CS7 | baud;
-	new.c_iflag = IGNBRK;
-	new.c_oflag = 0;
-	new.c_lflag = 0;
-	new.c_cc[VMIN]  = 1;
-	new.c_cc[VTIME] = 0;
+	tio.c_cflag = CREAD | CLOCAL | HUPCL | CS7 | baud;
+	tio.c_iflag = IGNBRK;
+	tio.c_oflag = 0;
+	tio.c_lflag = 0;
+	tio.c_cc[VMIN]  = 1;
+	tio.c_cc[VTIME] = 0;
 
-	if (tcsetattr(orb->fd, TCSANOW, &new) < 0) {
+	if (tcsetattr(orb->fd, TCSANOW, &tio) < 0) {
 		GIIDPRINT("tcsetattr failed.\n");
 /*		close(orb->fd);		*/
 /*		return GGI_ENODEVICE;		*/
 	}
 
 	/* set up RTS and DTR modem lines */
-
 	if ((dtr >= 0) || (rts >= 0)) {
-
+#ifdef HAVE_TIOCMSET
 		unsigned int modem_lines;
 
 		if (ioctl(orb->fd, TIOCMGET, &modem_lines) == 0) {
@@ -392,6 +391,12 @@ static int do_spaceorb_open(gii_input *inp, char *filename,
 			
 			ioctl(orb->fd, TIOCMSET, &modem_lines);
 		}
+#else /* HAVE_TIOCMSET */
+		fprintf(stderr,
+			"input-spaceorb: warning, this system does not"
+			" support TIOCMSET\n"
+			"        device may not work as expected\n");
+#endif /* HAVE_TIOCMSET */
 	}
 
 	return 0;
@@ -477,7 +482,7 @@ static void parse_options(char *opt, int *baud, int *dtr, int *rts)
 
 
 static inline int
-GII_spaceorb_init(gii_input *inp, char *typename)
+GII_spaceorb_init(gii_input *inp, char *typname)
 {
 	SpaceOrbHook *orb = SPACEORB_HOOK(inp);
 	char devname[256];
@@ -493,7 +498,7 @@ GII_spaceorb_init(gii_input *inp, char *typename)
 
 	/* parse the spaceorb specifier */
 	
-	parse_spaceorb_specifier(typename, devname, options);
+	parse_spaceorb_specifier(typname, devname, options);
 	parse_options(options, &baud, &dtr, &rts);
 
 	if (strcmp(devname, "none") == 0) {
@@ -672,14 +677,6 @@ static gii_cmddata_getvalinfo spaceorb_valinfo[6] =
     }
 };
 
-static gii_deviceinfo xdevinfo =
-{
-	NULL,
-	0,
-	&spaceorb_devinfo,
-	spaceorb_valinfo
-};
-
 static int GII_spaceorb_senddevinfo(gii_input *inp)
 {
 	gii_cmddata_getdevinfo *DI;
@@ -789,6 +786,10 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 	if (args && *args) {
 		spec = (char *) args;
 	}
+	
+	if(_giiRegisterDevice(inp,&spaceorb_devinfo,spaceorb_valinfo)==0) {
+		return GGI_ENOMEM;
+	}
 
 	if ((ret = GII_spaceorb_init(inp, spec)) < 0) {
 		return ret;
@@ -803,14 +804,12 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 	inp->GIIeventpoll = GII_spaceorb_poll;
 	inp->GIIclose = GII_spaceorb_close;
 	inp->GIIsendevent = GII_spaceorb_sendevent;
-	inp->devinfo    = &xdevinfo;
-	xdevinfo.origin = inp->origin;
 
 	inp->targetcan = emKey | emValuator;
 	inp->GIIseteventmask(inp, emKey | emValuator);
 
 	inp->maxfd = SPACEORB_HOOK(inp)->fd + 1;
-	FD_SET(SPACEORB_HOOK(inp)->fd, &inp->fdset);
+	FD_SET((SPACEORB_HOOK(inp)->fd), &inp->fdset);
 
 	/* Send initial cmdDevInfo event */
 	GII_spaceorb_senddevinfo(inp);
