@@ -1,4 +1,4 @@
-/* $Id: input.c,v 1.23 1999/03/20 15:28:23 becka Exp $
+/* $Id: input.c,v 1.4.2.2 2003/02/01 14:33:32 cegger Exp $
 ******************************************************************************
 
    Input-stdin: initialization
@@ -29,7 +29,9 @@
 #include <string.h>
 #include <ctype.h>
 
+#include "config.h"
 #include <ggi/internal/gii-dl.h>
+#include <ggi/internal/gii_debug.h>
 
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
@@ -220,14 +222,6 @@ static gii_cmddata_getdevinfo devinfo =
 	0				/* no valuators */
 };
 
-static gii_deviceinfo xdevinfo =
-{
-	NULL,
-	0,
-	&devinfo,
-	NULL
-};
-
 static void send_devinfo(gii_input *inp)
 {
 	gii_event ev;
@@ -241,7 +235,7 @@ static void send_devinfo(gii_input *inp)
 	ev.any.origin = inp->origin;
 	ev.cmd.code   = GII_CMDCODE_GETDEVINFO;
 
-	dinfo = (gii_cmddata_getdevinfo *) &ev.cmd.data;
+	dinfo = (gii_cmddata_getdevinfo *) ev.cmd.data;
 	*dinfo = devinfo;
 
 	_giiEvQueueAdd(inp, &ev);
@@ -302,6 +296,12 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 	if ((priv = malloc(sizeof(stdin_priv))) == NULL) {
 		return GGI_ENOMEM;
 	}
+
+	if(_giiRegisterDevice(inp,&devinfo,NULL)==0) {
+		free(priv);
+		return GGI_ENOMEM;
+	}
+
 	inp->priv = priv;
         
 	if (tolower((int)stdin_options[1].result[0]) != 'n') {
@@ -326,8 +326,6 @@ int GIIdlinit(gii_input *inp, const char *args, void *argptr)
 	inp->GIIsendevent = GIIsendevent;
 	inp->GIIeventpoll = GII_stdin_poll;
 	inp->GIIclose = GII_stdin_close;
-	inp->devinfo    = &xdevinfo;
-	xdevinfo.origin = inp->origin;
 
 	send_devinfo(inp);
 
